==> ideaIC-201.6668.113-sources.jar: com/android/tools/idea/gradle/project/sync/hyperlink/SetCmakeDirHyperlink.kt <==
/*
 * Copyright (C) 2019 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.project.sync.hyperlink

import com.android.tools.idea.gradle.project.sync.GradleSyncInvoker
import com.android.tools.idea.gradle.util.LocalProperties
import com.android.tools.idea.project.hyperlink.NotificationHyperlink
import com.intellij.openapi.project.Project
import com.google.wireless.android.sdk.stats.GradleSyncStats.Trigger.TRIGGER_QF_CMAKE_INSTALLED
import java.io.File

/**
 * Set the value of cmake.dir to the given value then trigger a res-sync.
 */
class SetCmakeDirHyperlink(private val path : File, text : String) : NotificationHyperlink(
  "use.existing.cmake:$path", text) {
  override fun execute(project: Project) {
    val localProperties = LocalProperties(project)
    localProperties.androidCmakePath = path
    localProperties.save()
    GradleSyncInvoker.getInstance().requestProjectSync(
      project,
      TRIGGER_QF_CMAKE_INSTALLED)
  }
}

==> ideaIC-2019.3-sources.jar: com/android/tools/idea/gradle/project/sync/hyperlink/SetCmakeDirHyperlink.kt <==
/*
 * Copyright (C) 2019 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.project.sync.hyperlink

import com.android.tools.idea.gradle.project.sync.GradleSyncInvoker
import com.android.tools.idea.gradle.util.LocalProperties
import com.android.tools.idea.project.hyperlink.NotificationHyperlink
import com.intellij.openapi.project.Project
import com.google.wireless.android.sdk.stats.GradleSyncStats.Trigger.TRIGGER_QF_CMAKE_INSTALLED
import java.io.File

/**
 * Set the value of cmake.dir to the given value then trigger a res-sync.
 */
class SetCmakeDirHyperlink(private val path : File, text : String) : NotificationHyperlink(
  "use.existing.cmake:$path", text) {
  override fun execute(project: Project) {
    val localProperties = LocalProperties(project)
    localProperties.androidCmakePath = path
    localProperties.save()
    GradleSyncInvoker.getInstance().requestProjectSyncAndSourceGeneration(
      project,
      TRIGGER_QF_CMAKE_INSTALLED)
  }
}
